# Install Guide

## System Requirements

Make sure your system meets these requirements:

* Operating system: **pstk** requires Ubuntu 11 or later (12.04 preferred)
* RAM: 2GB.
* Disk space: 2GB

## Install QSTK

**TODO**: Installation steps need to be reviewed and updated.

Once you have Ubuntu Installed, start Ubuntu and follow these commands to get Ubuntu working.

* Step 1: Create a conda env
* Step 2: Download & Install
* Step 3: Testing the Installation was correct, please run the following commands. Please read the complete output to check if everything looks okay, specially version numbers.

```
cd Examples
python Validation.py
```

## Further Testing pftk

There are several example programs in the `Examples/Basic` directory.  We suggest you start with taking a look at the data access example in `Examples/Basic/tutorial1.py`. This example will create pdfs in your basic directory.  Take a look at the code there to see how it works.

Now take pftk for a test drive. Take a look at [Tutorial 1](tutorial_1.md)
